cdn 上传工具

# 依赖

node > 8.x

# 示例

```javascript
const upload = require('easeftp/upload').add;

// upload('{,!(node_modules)/**/}*.js',{
upload(['**/*.js','**/*.html'],{
    username:"...",  //用户名
    password:"...",  //密码
    path:'f2e/test',    //cdn线上路径
    debug:true,         //是否开启日志打印 ， 可缺省，默认为false
    cwd:'./dist',        //指定匹配的根目录
    exclude:['index.html','*test.js'] //指定排除不上传的文件
}).then(({urls,details}) =>{
    console.log(urls);      //上传成功的访问url
},({urls,details}) => {
     console.log(details);   //所有详细信息
})
```

# 注意
> * 服务器为UTF8编码
> * 账号密码要单独建立config文件，以免错误的提交到git上


# API

`function add(pattern , {username, password, path, debug, cwd, strict, globOption, debugFn} )`

## pattern

string | array , 必填

支持glob语法，内部通过glob组件匹配文件。
语法详情参考:[glob](https://www.npmjs.com/package/glob)

## username , password 

string,必填

无权限的用户，需要先申请权限

## path

string | function(filePath) ,默认为`"f2e/test"`

设置上传cdn后的url路径。

上传成功后的url地址为: `https://static.ws.126.net/163/${path}/${fileName}` 例如 `path:'f2e/test'`， 则上传成功后，访问路径为:`https://static.ws.126.net/163/f2e/test/xxx`。

也可以设置为function类型，接收string类型的filePath参数，为即将上传的文件绝对路径，转化为url路径。
例如;
```javascript
upload('**/*.js', {
    username:'xxx',password:'xxx',
    cwd:'./dist',
    path(filePath){
        if(filePath.indexOf('test.js')){
            return 'f2e/test'
        }
        else{
            return 'f2e/dist'
        }
    }
}).then(({urls, details}) => {
    console.log(urls);
   /*[ 'https://static.ws.126.net/163/f2e/dist/app.js',
       'https://static.ws.126.net/163/f2e/test/test.js' ]*/
})


```

## debug 

bool,默认为 false

是否在控制台开启调试打印信息

## cwd

string,默认为 process.cwd().

指定查找的目录。

当pattern为相对路径时，在会在cwd下查找匹配的文件。例如:
```javascript
const {add: upload} = require('easeftp/upload');
const {username,password}=require('./config');

//只上传dist目录下的js文件。
upload('*.js',{
    username:username, 
    password:password, 
    path:'f2e/test', 
    cwd:'./dist'
});
```

cwd可以是绝对路径,也可以是相对路径。如果cwd为相对路径，是相对于process.cwd()的。

## strict

bool,默认为true.

是否严格限定上传的目录结构。
为true时，上传到cdn的目录结构和本地目录结构一致，例如:

```javascript

/*
假设dist目录结构为:
./dist
├── app.js
└── lib
    └── ajax.js
    
*/
upload('**/*.js', {
    username:'xxx',password:'xxx',
    path: 'f2e/test/',
    cwd:'./dist',
    strict:true
}).then(({urls, details}) => {
    console.log(urls);
   /*[ 'https://static.ws.126.net/163/f2e/test/app.js',
       'https://static.ws.126.net/163/f2e/test/lib/ajax.js' ]*/
})

upload('**/*.js', {
    username:'xxx',password:'xxx',
    path: 'f2e/test/',
    cwd:'./dist',
    strict:false,
}).then(({urls, details}) => {
    console.log(urls);
   /*   [ 'https://static.ws.126.net/163/f2e/test/app.js',
          'https://static.ws.126.net/163/f2e/test/ajax.js' ]*/
})

```

## globOption

默认为空对象{}

组件内部使用 glob 组件进行文件匹配。

通过globOption向 glob 组件传递参数。

参数详情参考: [glob](https://www.npmjs.com/package/glob)


## debugFn

function(txt,type)

设置打印日志的函数。默认使用console.log打印日志，可以通过传入debugFn自定义日志打印。

type参数为字符串，目前确定有以下三种值: "log","error","success"



----------


# Version 1


## 示例
```javascript
var easeftp = require('easeftp');
easeftp.verify({
	"username": "...",
	"password": "..."
}).then(function() {
	return easeftp.upload({
		online: "test/test1/......",
		file: "绝对路径", 	// 需要上传的文件路径
		files: "绝对路径", 	// 需要上传的文件夹路径
						  	// 文件和文件夹只能选择其一，否则按照文件上传处理
		exclude:["*.js","**.js","..."]   // 排除其中不上传的文件
	})
}).then(([successArr,failArr]) => {
	// successArr 	上传成功
	// failArr 		上传失败
	// complete
})
```

## 说明

v1内部还是require的`easeftp/upload`，只不过兼容之前的参数形式。

如果要使用原v1的代码，使用如下形式:

```javascript
var easeftp = require('easeftp/index_v1');
```



-------

http://static.ws.126.net/163/{path}

注意
> * 服务器为UTF8编码
> * 账号密码要单独建立config文件，以免错误的提交到git上**  
